package log

import (
	"io"

	"go.uber.org/zap"
	"go.uber.org/zap/zapcore"
)

type writerLogger struct {
	log   *zap.SugaredLogger
	level zapcore.Level
}

func AsWriter(log *zap.SugaredLogger, level zapcore.Level) io.Writer {
	return &writerLogger{log: log}
}

func (w *writerLogger) Write(p []byte) (n int, err error) {
	switch w.level {
	case zapcore.DebugLevel:
		w.log.Debug(string(p))
	case zapcore.InfoLevel:
		w.log.Info(string(p))
	case zapcore.WarnLevel:
		w.log.Warn(string(p))
	case zapcore.ErrorLevel:
		w.log.Error(string(p))
	case zapcore.DPanicLevel:
		w.log.DPanic(string(p))
	case zapcore.PanicLevel:
		w.log.Panic(string(p))
	case zapcore.FatalLevel:
		w.log.Fatal(string(p))
	}
	return len(p), nil
}
